#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "Serial.h"
#include "BuildLog.h"
#include "Project.h"

#define FORMAT_BUILD_LOG_DIR "%s/%d"
#define FORMAT_BUILD_LOG_FILE "%s/%d/%d-p%d.log"

struct BuildLog {
    struct Project *project;
};

void
BuildLog_free(struct BuildLog *bl)
{
    if (bl == NULL)
	return;
    Project_free(bl->project);
    free(bl);
}

struct BuildLog *
BuildLog_create(const char *projectID)
{
    struct BuildLog *bl;

    if ((bl = (struct BuildLog *)malloc(sizeof(*bl))) == NULL) {
	return NULL;
    }
    bl->project = NULL;

    if ((bl->project = Project_create(projectID)) == NULL) {
	BuildLog_free(bl);
	return NULL;
    }
    return bl;
}

void
BuildLog_getBasePath(struct BuildLog *bl, struct Serial *serial,
	             char *path, size_t pathLen)
{
    int num = Serial_getInt(serial);

    snprintf(path, pathLen, FORMAT_BUILD_LOG_DIR,
	     Project_getBasePath(bl->project), num/100);
}

void
BuildLog_getPath(struct BuildLog *bl, struct Serial *serial, int k,
		 char *path, size_t pathLen)
{
    int num = Serial_getInt(serial);

    snprintf(path, pathLen, FORMAT_BUILD_LOG_FILE, 
	     Project_getBasePath(bl->project), num/100, num, k);
}
